@@ -1,8 +1,8 @@
 import numpy as np
 import matplotlib.pyplot as plt
 from matplotlib.axes import Axes
-from .show import show,show_points
-from ..process.calibration.rotation import get_Qvector_from_Rvector,get_Rvector_from_Qvector
+from py4DSTEM.visualize.show import show,show_points
+from py4DSTEM.process.calibration.rotation import get_Qvector_from_Rvector,get_Rvector_from_Qvector
 
 def show_selected_dp(datacube,image,rx,ry,figsize=(12,6),returnfig=False,
                      pointsize=50,pointcolor='r',scaling='log',**kwargs):
